__version__ = "2.4.20"

if __package__ or "." in __name__:
    from . import _DynamsoftCodeParser
else:
    import _DynamsoftCodeParser

from typing import List

from enum import IntEnum

if __package__ or "." in __name__:
    from .core import *
else:
    from core import *



class EnumMappingStatus(IntEnum):
    MS_NONE = _DynamsoftCodeParser.MS_NONE
    MS_SUCCEEDED = _DynamsoftCodeParser.MS_SUCCEEDED
    MS_FAILED = _DynamsoftCodeParser.MS_FAILED


class EnumValidationStatus(IntEnum):
    VS_NONE = _DynamsoftCodeParser.VS_NONE
    VS_SUCCEEDED = _DynamsoftCodeParser.VS_SUCCEEDED
    VS_FAILED = _DynamsoftCodeParser.VS_FAILED

class ParsedResultItem(CapturedResultItem):
    """
    The ParsedResultItem class represents a parsed result item generated by code parser engine.

    Methods:
        get_code_type(self) -> str: Gets the code type of the parsed result.
        get_field_value(self, field_name: str) -> str: Gets the value of a specified field from the parsed result.
        get_field_mapping_status(self, field_name: str) -> int: Gets the mapping status of a specified field from the parsed result.
        get_field_validation_status(self, field_name: str) -> int: Gets the validation status of a specified field from the parsed result.
        get_json_string(self) -> str: Gets the parsed result as a JSON formatted string.
    """
    thisown = property(
        lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag"
    )

    def __init__(self):
        raise AttributeError("No constructor defined - class is abstract")

    def get_json_string(self) -> str:
        """
        Gets the parsed result as a JSON formatted string.

        Returns:
            A JSON formatted string representing the full parsed result.
        """
        return _DynamsoftCodeParser.CParsedResultItem_GetJsonString(self)

    def get_code_type(self) -> str:
        """
        Gets the code type of the parsed result.

        Returns:
            A string value representing the code type.
        """
        return _DynamsoftCodeParser.CParsedResultItem_GetCodeType(self)

    def get_field_value(self, field_name: str) -> str:
        """
        Gets the value of a specified field from the parsed result.

        Args:
            field_name(str): The name of the field.

        Returns:
            A string representing the specified field value.
        """
        return _DynamsoftCodeParser.CParsedResultItem_GetFieldValue(self, field_name)

    def get_field_mapping_status(self, field_name: str) -> int:
        """
        Gets the mapping status of a specified field from the parsed result.

        Args:
            field_name(str): The name of the field.

        Returns:
            An EnumMappingStatus value representing the mapping status of a specified field.
        """
        return _DynamsoftCodeParser.CParsedResultItem_GetFieldMappingStatus(
            self, field_name
        )

    def get_field_validation_status(self, field_name: str) -> int:
        """
        Gets the validation status of a specified field from the parsed result.

        Args:
            field_name(str): The name of the field.

        Returns:
            An EnumValidationStatus value representing the validation status of a specified field.
        """
        return _DynamsoftCodeParser.CParsedResultItem_GetFieldValidationStatus(
            self, field_name
        )


_DynamsoftCodeParser.CParsedResultItem_register(ParsedResultItem)


class ParsedResult(object):
    """
    The ParsedResult class represents the results of a code parser process.

    Methods:
        get_original_image_hash_id(self) -> str: Gets the hash ID of the source image.
        get_original_image_tag(self) -> ImageTag: Gets the tag of the source image.
        get_items(self) -> List[ParsedResultItem]: Gets all the parsed result items.
        get_error_code(self) -> int: Gets the error code of the parsed result, if an error occurred.
        get_error_string(self) -> str: Gets the error message of the parsed result, if an error occurred.
    """
    thisown = property(
        lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag"
    )
    __destroy__ = _DynamsoftCodeParser.CParsedResult_Release

    def __init__(self):
        raise AttributeError("No constructor defined - class is abstract")

    def get_original_image_hash_id(self) -> str:
        """
        Gets the hash ID of the source image.

        Returns:
            A string containing the hash ID of the source image.
        """
        return _DynamsoftCodeParser.CParsedResult_GetOriginalImageHashId(self)

    def get_original_image_tag(self) -> ImageTag:
        """
        Gets the tag of the source image.

        Returns:
            An ImageTag object representing the tag of the source image.
        """
        return _DynamsoftCodeParser.CParsedResult_GetOriginalImageTag(self)

    def get_items(self) -> List[ParsedResultItem]:
        """
        Gets all the parsed result items.

        Returns:
            A ParsedResultItem list.
        """
        list = []
        count = _DynamsoftCodeParser.CParsedResult_GetItemsCount(self)
        for i in range(count):
            list.append(_DynamsoftCodeParser.CParsedResult_GetItem(self, i))
        return list

    def get_error_code(self) -> int:
        """
        Gets the error code of the parsed result, if an error occurred.

        Returns:
            The error code of the parsed result, or 0 if no error occurred.
        """
        return _DynamsoftCodeParser.CParsedResult_GetErrorCode(self)

    def get_error_string(self) -> str:
        """
        Gets the error message of the parsed result, if an error occurred.

        Returns:
            A string containing the error message of the parsed result, or an empty string if no error occurred.
        """
        return _DynamsoftCodeParser.CParsedResult_GetErrorString(self)


_DynamsoftCodeParser.CParsedResult_register(ParsedResult)


class CodeParserModule(object):
    """
    The CodeParserModule class defines general functions in the code parser module.

    Methods:
        get_version() -> str: Returns a string representing the version of the code parser module.
    """
    thisown = property(
        lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag"
    )

    @staticmethod
    def get_version() -> str:
        """
        Returns a string representing the version of the code parser module.

        Returns:
            A string representing the version of the code parser module.
        """
        return __version__ + " (Algotithm " + _DynamsoftCodeParser.CCodeParserModule_GetVersion() + ")"

    def __init__(self):
        _DynamsoftCodeParser.CCodeParserModule_init(
            self, _DynamsoftCodeParser.new_CCodeParserModule()
        )

    __destroy__ = _DynamsoftCodeParser.delete_CCodeParserModule


_DynamsoftCodeParser.CCodeParserModule_register(CodeParserModule)
